# SFSD
A python module made for the educational course "SFSD" which represents "Files structures and file handeling", this course is for 2nd year students at the grand schools of computer science, and can be used by any engineer looking to handle files at their base level 
